searchData={"items":[{"type":"module","title":"Lexgen.Generator","doc":"","ref":"Lexgen.Generator.html"},{"type":"function","title":"Lexgen.Generator.build_code/2","doc":"Given a list of Lexicon structs, generates Elixir source code files to the given `output` directory.","ref":"Lexgen.Generator.html#build_code/2"},{"type":"function","title":"Lexgen.Generator.generate/2","doc":"Reads all Lexicons in the given path and generates code for them.\n\nThe `input` path argument is given to `Lexgen.Generator.read_lexicons/1`. See that function for more information about the accepted format of the input path.\n\nIf `output` is given, it is assumed to be a path to a directory where all of the generated source files will be written. The directory will be created if it does not exist.","ref":"Lexgen.Generator.html#generate/2"},{"type":"function","title":"Lexgen.Generator.read_lexicon/1","doc":"Given a path to a Lexicon JSON file, reads the file and parses it into a Lexicon struct.","ref":"Lexgen.Generator.html#read_lexicon/1"},{"type":"function","title":"Lexgen.Generator.read_lexicons/1","doc":"Given a path to one or more Lexicon JSON files, reads the files and parses them into a list of Lexicon structs.\n\nNote: Uses `Path.wildcard/1` to convert `path` to a list of paths.","ref":"Lexgen.Generator.html#read_lexicons/1"},{"type":"module","title":"Lexgen.Lexicon","doc":"Stores information about a Lexicon source JSON file.\n\nAccording to the [AT Protocol Lexicon Specification](https://atproto.com/specs/lexicon):\n\n- A Lexicon is a JSON file.\n- Each Lexicon can have *AT MOST* one primary type.\n- Each `record` and some `object` types require the use of a special `$type` key. This should be the Lexicon's NSID.\n- References to the \"main\" definition of a Lexicon should *always* exclude the suffix (`#main`). While some scenarios accept using a suffix of `#main`, some scenarios do not, but *all* scenarios accept omitting the suffix for a \"main\" definition.","ref":"Lexgen.Lexicon.html"},{"type":"function","title":"Lexgen.Lexicon.constraint_keys/1","doc":"","ref":"Lexgen.Lexicon.html#constraint_keys/1"},{"type":"function","title":"Lexgen.Lexicon.parse/1","doc":"Parses a Lexicon JSON string into a Lexicon struct. Also accepts a JSON-decoded map.","ref":"Lexgen.Lexicon.html#parse/1"},{"type":"function","title":"Lexgen.Lexicon.parse_def/3","doc":"Parses a single definition from a Lexicon JSON file.","ref":"Lexgen.Lexicon.html#parse_def/3"},{"type":"function","title":"Lexgen.Lexicon.parse_defs/1","doc":"Parses the `defs` object from a Lexicon JSON file. This assumes that `defs` in the Lexicon struct is an unmodified map from the decoded JSON source.","ref":"Lexgen.Lexicon.html#parse_defs/1"},{"type":"function","title":"Lexgen.Lexicon.parse_output/2","doc":"","ref":"Lexgen.Lexicon.html#parse_output/2"},{"type":"function","title":"Lexgen.Lexicon.split_nsid/1","doc":"Splits an NSID into two components: the \"namespace\" and the \"id\".\n\nFor example, `app.bsky.feed.getFeed` would split into `app.bsky.feed` and `getFeed`.","ref":"Lexgen.Lexicon.html#split_nsid/1"},{"type":"type","title":"Lexgen.Lexicon.t/0","doc":"","ref":"Lexgen.Lexicon.html#t:t/0"},{"type":"function","title":"Lexgen.Lexicon.title_nsid/1","doc":"Converts an NSID into a title-cased string.\n\nFor example, `app.bsky.feed.getFeed` becomes `App.Bsky.Feed.GetFeed`.","ref":"Lexgen.Lexicon.html#title_nsid/1"},{"type":"module","title":"Lexgen.Schema","doc":"Generates code snippets for schema generation of `record` definitions.","ref":"Lexgen.Schema.html"},{"type":"function","title":"Lexgen.Schema.constraints/1","doc":"","ref":"Lexgen.Schema.html#constraints/1"},{"type":"function","title":"Lexgen.Schema.deref_main/2","doc":"","ref":"Lexgen.Schema.html#deref_main/2"},{"type":"function","title":"Lexgen.Schema.fields/1","doc":"","ref":"Lexgen.Schema.html#fields/1"},{"type":"function","title":"Lexgen.Schema.operations/1","doc":"","ref":"Lexgen.Schema.html#operations/1"},{"type":"function","title":"Lexgen.Schema.safe_key/2","doc":"","ref":"Lexgen.Schema.html#safe_key/2"},{"type":"module","title":"Lexgen.Structs","doc":"","ref":"Lexgen.Structs.html"},{"type":"function","title":"Lexgen.Structs.fields/1","doc":"","ref":"Lexgen.Structs.html#fields/1"},{"type":"function","title":"Lexgen.Structs.specs/1","doc":"","ref":"Lexgen.Structs.html#specs/1"},{"type":"module","title":"Lexgen.Types","doc":"","ref":"Lexgen.Types.html"},{"type":"function","title":"Lexgen.Types.default_value/1","doc":"Returns the default value for a given field.\n\nIf the type def already has a `default` key, it is returned as-is. If no explicit default value is provided, the `type` of the field will determine the default value.","ref":"Lexgen.Types.html#default_value/1"},{"type":"function","title":"Lexgen.Types.ref_to_type/2","doc":"Convert a `ref` string to a module name.","ref":"Lexgen.Types.html#ref_to_type/2"},{"type":"function","title":"Lexgen.Types.to_ecto/1","doc":"Convert a field definition to an Ecto type.","ref":"Lexgen.Types.html#to_ecto/1"},{"type":"function","title":"Lexgen.Types.to_native/2","doc":"Convert a field definition to a native Elixir type.","ref":"Lexgen.Types.html#to_native/2"},{"type":"module","title":"Lexgen.Xrpc","doc":"","ref":"Lexgen.Xrpc.html"},{"type":"function","title":"Lexgen.Xrpc.param_names/1","doc":"","ref":"Lexgen.Xrpc.html#param_names/1"},{"type":"function","title":"Lexgen.Xrpc.params_spec/1","doc":"","ref":"Lexgen.Xrpc.html#params_spec/1"},{"type":"function","title":"Lexgen.Xrpc.required_param_names/1","doc":"","ref":"Lexgen.Xrpc.html#required_param_names/1"},{"type":"function","title":"Lexgen.Xrpc.xrpc_target/1","doc":"","ref":"Lexgen.Xrpc.html#xrpc_target/1"},{"type":"task","title":"mix lexgen","doc":"Generates Elixir source code from AT Protocol lexicons. Lexicons are JSON files which define records, objects, queries, and other parts of the AT Protocol data model.\n\nBy default, this will generate files to `./lib/atproto`. The destination folder can be overridden using the `--output` (or `-o`) option.\n\nEvery non-option argument passed in is assumed to be a path to one or more Lexicon files. If specifying more than one Lexicon input, you may either specify each file individually or use glob-style file patterns (e.g. `lexicons/**/*.json`).","ref":"Mix.Tasks.Lexgen.html"},{"type":"task","title":"Options - mix lexgen","doc":"- `-o, --output`: The destination folder for the generated files.\n- `-d, --delete`: Deletes all existing files in the destination folder before generating new files.","ref":"Mix.Tasks.Lexgen.html#module-options"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}